``pants.contrib.http.client``
*****************************

.. automodule:: pants.contrib.http.client


HTTPClient
==========

.. autoclass:: HTTPClient
   :members: on_response, get, post, process


ClientHelper
============

.. autoclass:: ClientHelper
   :members: fetch


HTTPResponse
============

.. autoclass:: HTTPResponse
   :members: cookies, full_url
